Module: Google::Apps::Events::Subscriptions
- Defined in:
- lib/google/apps/events/subscriptions.rb,
lib/google/apps/events/subscriptions/version.rb
Constant Summary collapse
- VERSION =
"1.3.0"
Class Method Summary collapse
-
.subscriptions_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for SubscriptionsService.
-
.subscriptions_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the SubscriptionsService service is supported by the current client.
Class Method Details
.subscriptions_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for SubscriptionsService.
By default, this returns an instance of
Google::Apps::Events::Subscriptions::V1::SubscriptionsService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the SubscriptionsService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the SubscriptionsService service. You can determine whether the method will succeed by calling subscriptions_service_available?.
About SubscriptionsService
A service that manages subscriptions to Google Workspace events.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/google/apps/events/subscriptions.rb', line 58 def self.subscriptions_service version: :v1, transport: :grpc, &block require "google/apps/events/subscriptions/#{version.to_s.downcase}" package_name = Google::Apps::Events::Subscriptions .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Apps::Events::Subscriptions.const_get(package_name).const_get(:SubscriptionsService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.subscriptions_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the SubscriptionsService service is supported by the current client. If true, you can retrieve a client object by calling subscriptions_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SubscriptionsService service, or if the versioned client gem needs an update to support the SubscriptionsService service.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/google/apps/events/subscriptions.rb', line 82 def self.subscriptions_service_available? version: :v1, transport: :grpc require "google/apps/events/subscriptions/#{version.to_s.downcase}" package_name = Google::Apps::Events::Subscriptions .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Apps::Events::Subscriptions.const_get package_name return false unless service_module.const_defined? :SubscriptionsService service_module = service_module.const_get :SubscriptionsService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |